---
layout: page
title: Just Motion
author: Chip Brock
chapter: 1

summary: You like to move it move it. Move it.
published: true
---
&nbsp;

<p class="message" markdown="1">
Our journey to understanding the modern physics of elementary particles and cosmology begins in 1564, the year that the world gained William Shakespeare and lost Michelangelo. On February 15th in a modest house at the end of a short street in Pisa---not far from the Arno river---a struggling musician and his wife had their first of five or six children, a son. The boy was like his father in many ways: headstrong and intelligent, an original thinker even at an early age.<br><br>
Galileo Galilei lived a long and tempestuous life. When he began his work as a mathematician, the world was a place of magic and superstition. An object moved according to mysterious rules, fast or slow, whether straight or curved vaguely according to its Nature, its fire-air-water-earth composition. Explaining, much less predicting, how things moved wasn't even a serious question. Philosopher's owned that subject and their thinking was rigid and unimaginative. By the time he died, ill and blind at the age of 77, Galileo had established our modern relationship with Nature. His scientific descendents no longer wondered *whether* the world was knowable and regular. Their research program became---and is now--- *what are the precise mathematical rules* that describe the motions---of all things. Vagueness became unwelcome. Precision was the game. <br><br>
Modeling motion was the beginning of physics and this lesson tells that story.
</p>

## Contents
{:.no_toc}

* Toc
{:toc}

### Goals of this lesson:

I'd like you to Understand:

* How to calculate distance, time, and speed for uniform and constantly accelerated, linear motion
* That falling objects all have the same acceleration near the Earth
* How to graph simple motion parameters
* That physics models the ideal regularities of Nature

I'd like you to Appreciate:

* The algebraic narratives in the development of the formulas
* The shape of the trajectory of a projectile
* That a projectile’s motion is made of two components with different accelerations

I'd like you to become Familiar With:

* Ideas of motion before Galileo
* Some of Galileo’s life
* Galileo’s experiments with motion

# A Little Bit of Galileo

"Galileo." What comes to mind when you hear his name? That trial? A famous experiment involving a tower? The "father of physics"? All things you might find in a short search. But there's much more about this complicated man, now the subject fables that quickly grew up around his life and his sad end.

Galileo Galilei was a loyal friend to many---a famous man in Europe---and at the same time he attracted fierce and dangerous enemies. He was an accomplished musician and literary critic and yet not above vulgar student poetry aimed at stuffy professors or impetuous, even petulant, public letters mocking self-righteous authorities. He was passionately independent and yet a shameless flatterer of the wealthy and powerful. His science was novel, bold, and cutting-edge, but he couldn't shake allegiance to perfectly circular planetary orbits. He was, and still is an enigma.

 He's a fascinating character from a fascinating time---a contemporary of Shakspeare, Elizabeth I, Francis Bacon, Johannes Kepler, Tycho de Brahe, and Rene Descartes. A cosmopolitan public figure and intellectual, yet a homebody---never straying beyond Rome, Florence, and Venice.

Galileo studied many topics in what he would have called natural philosophy, but two major scientific paths will concern us: his research and enduring conclusions about motion and astronomy. In this lesson, we'll follow his ideas about motion and postpone his astronomy...and the famous trial...for a later lesson.


>**great expectations**<br>
><hr>
>Did you ever wonder why Galileo seems to have only one name? There's a story about that. One of his great-great-(great?) grandfathers was the original Florentine "Galileo" - a 15th century medical doctor and civil leader of the family Bonaiuti. So significant was Dr Galileo in Florence that the middle-class Bonaiuti family renamed itself "Galilei." Our Galileo Galilei’s two identical names was a subtle parental reminder that he was expected to do great things. As a proud citizen of Florence.

<aside style="font-size:80%; font-family:sans-serif; color:grey;float:right;width:40%;padding-left:5px;">  <figure><img src="../../assets/motion/figs/Galileo_sketch.jpg" alt=" - "/><figcaption>Galileo Galilei    1564-1642 <br>I do not
feel obliged to believe that the same God who has endowed us with sense,
reason, and intellect has intended us to forgo their
use.</figcaption></figure> </aside>

Except he wasn't!  Our Galileo was born in Pisa but always considered himself a citizen of Florence, although he lived there after the age of 10 when his father could leave work in his wife's family business. Vincenzo Galileo was a musician and while his family maintained its dignity,  their circumstances never lived up to their legendary ancestor.  Vincenzo eventually returned to Florence performing and composing  full time and established young Galileo's primary education nearby. Vincenzo's plan was that his son would be a doctor. No discussion. And off to the University of Padua he was sent.

## As a Student

While a medical student, Galileo accidentally discovered an aptitude for mathematics that led him to an intense but clandestine math program with the Court Mathematician to the Grand Duke of Tuscany. After a tough negotiation at home, he eventually abandoned medicine, leaving the university a year short of his degree. By this time he was doing original mathematical research (in geometry) and had caught the attention of scholars in Pisa and Rome.

Galileo made a name for himself at the university---as shockingly disrespectful. Even at a young age, he was allergic to fools and he found the faculty overstocked in that category.[^fools]  He was also impossibly resistant to the regimented intellectual system of all European universities: in every subject, philosophy, mathematics, law, logic, rhetoric, and astronomy it was Aristotle, all the time. Particularly galling to Galileo was Aristotle's physics and there he was in good company since Aristotle's ideas about motion had not made sense to anyone for two centuries, but his authority was absolute. Galileo—like his father—didn’t “do” authority.

[^fools]: He wrote low poetry making fun of them and their sometimes affection for brothels.

He lived at home for three years and gave private mathematics lessons in Florence and Sienna while he cultivated patrons for help in finding a university position.  After some rejections, he succeeded...back at the University of Pisa as a lecturer of mathematics. Where his welcome was underwhelming.

His reputation as an original mathematician was growing when his father died. As a consequence he inherited the responsibility of a significant dowry for one married sister and responsibility to provide for the other’s. He spent the rest of his life in search of a higher salary and ways to augment his income, which as a lowly mathematician at Pisa was a quarter of that of a philosophy professor. He got his break when he was offered the position of Professor of Mathematics at the University of Padua, among the most prestigious universities in Europe and safely in the progressive Republic of Venice. It was at Padua where the Galileo magic happened.

# A Greek Version of Here to There

Look around you---everything is in flux. Things fall, birds fly, you move across a room, you throw a ball, the sun is in a different spot in the sky during the day, and the stars appear to move from east to west during the night. Why? How? Our experience shows that all events but those in the sky are individual events...all different in one way or another. Regular, reliable motions appear to be reserved for the celestial bodies.

The correct understanding of everyday motion was long incoming and by Galileo's time, everyone thought that Aristotle had naild it. Classical works had been out of reach of Europe until Greek philosophy and science essentially fell into Europe's lap in the form of hundreds of conflicting Arabic translations in the 1300s. Translation of Aristotle’s *Physics* from original Greek, to Arabic, and then to Latin did not make his ideas any less confused than they originally were.

Aristotle, revered as “The Philosopher,”  invented formal logic that taught people how to evaluate arguments. But while the Philosopher’s methods were refreshing, his ideas about motion were confused at best---but nonetheless became firmly stuck in the academic and Church communities where they were protected as *philosophy*, not as *science*.

Not until the end of the 16th century did Galileo shed Aristotle and lay the groundwork for the first systematic understanding of what it means for something to move. It took three centuries! Let's lay out the basics of The Philosopher's mechanics so we'll have something to shoot at.

## Aristotle's Mechanics and Astronomy

For Aristotle there were three kinds of motion: two "natural" and one "unnatural." Natural motion near the Earth was in a *straight line*, either *down*  or *up* relative to the center of the Universe, which he located at the center of the Earth. The speed of downward motion depended on the amount of “earthy” composition of the object, and so its weight. If there was a lot of earthiness---think a rock---the object went down. If it had the property of "lightness" (a quality that's foreign to us) it went up---think fire. So the apparent fact that every event we observe is a little different from every other event can be ascribed to the variations in real things' composition.

Natural motion beyond the orbit of the Moon was to be *circular* with every extraterrestrial body attached to its own rotating crystalline sphere. These spheres were all nested with common centers and rotated around the Earth to account for the apparently circular orbits that we see from the Earth. They included all of the known planets, the Sun, and the Moon...and even the stars all together in the outermost shell. All three natural motions just happened...um, naturally.

Unnatural motion was different. It required a pusher...an active force that was in physical contact with the object. Therein lay one of the most obvious flaws in his model.

It's child's play to make fun of these ideas. And I will. But  he was describing what he saw in his everyday life and trying to fit it together into his much bigger, intricately stitched-together philosophical structure. Pull at one piece of that system and the whole thing tumbles apart like a game of Jenga. So while his physics was bizarre and wrong, it stuck. It had to stick. But people knew for centuries that it had problems.[^cause]

[^cause]: There were a number of other issues with his physics, like his "four causes" which made things move because the had some desire to find a natural place. But we'll not go there. Okay. I'll go there a little. Motion was not only for moving objects in space. A cat growing into a kitten was a form of motion. A seed growing into a plant was a form of motion and the seed's desire was to reach that plant-ness as a matter of fulfillment. Now take this into the kind of motion that we care about---his Locomotion---and you'll see why I didn't go there. Much.

Galileo was the one person who changed the landscape and uncovered the modern notion of how things move, ridding the intellectual community of Aristotle’s baggage. He began to rebel while at Pisa where he wrote an unpublished manuscript, *de Motu* (“On Motion”). These were immature ideas, but he was onto something. One of his conclusions was right on: all objects fall at the same rate, contrary to Aristotle’s insistence that heavier objects fell faster. His data? Not the Leaning Tower of Pisa. That’s a myth. He just looked around him. And saw things differently.

# Getting From Here to There: At Constant Speed

Motion is both easiest and the hardest concept in physics. You've been dropping things since you were a toddler and you learned the hard way that if you drop something from a high place it will more likely break than from a low height. You learned that the harder you throw a ball, the faster it will leave your hand, the more damage it can do to a window, and the farther it will go before landing---and that it always comes down.

Since you started driving, you began to develop an intuition for  magnitudes of speeds and you do speed-arithmetic all the time: if you travel at 50 mph for 2 hours, you will have gone how far? 100 miles, right? In fact, you know a lot about speed and I wouldn't shock you if I wrote a sentence-equation that defines it:

$$\text{speed} = \text{distance traveled divided the time that it took}$$

Simple! But.

From our QS&BB perspective, there’s a lot to unpack about this simple mathematical sentence and it will all matter as we move ahead. Just a taste:

<aside style="font-size:80%; font-family:sans-serif; color:grey;float:right;width:30%;padding-left:20px; padding-bottom:20px;">  <figure><img src="../../assets/motion/figs/speedsign.png" width="100"  alt=" - "/><figcaption></figcaption></figure> </aside>
1. What are the units of speed? If the sign says "Speed Limit, 55," how fast is that? mph? meters/second? km per hour? furlongs per fortnight? It would be silly to just say “60” wouldn’t it. Wait. That’s exactly what our speed limit signs say. So you even intuit speed units.
2. If time doesn’t march on, we’ve not moved. But what is time? “The Big Business Man smiled. "'I do know what time is,' Tubby declared. He paused. 'Time,' he added slowly -- 'time is what keeps everything from happening at once...' [^time] We'll see time take on a new meaning.
3. The final frontier, Space, is either “just there” or it’s a relationship between two things. If all of the things in the universe disappeared, is there space left over? That's an old, contentious issue and maybe was finally solved by Einstein.
4. What’s the difference between space and time? In “speed” they are just two sides of the same coin, or two sides of the same ratio. But usually you think of them as different things. One’s not more important than the other is it? Eventually, we'll let Einstein chime in here.
5. Particular speeds seem to be important. Mr Galileo taught us about one and James Clerk Maxwell and Albert Einstein taught us about another. (There he is again.)

[^time]: This is often attributed to Einstein, Woody Allen, and John Wheeler! It actually comes from Ray Cummings' short story *The Time Professor* from 1921. Stick with me. You'll learn all sorts of odd facts.

From that simple word-equation, so sensible and so obvious, I've hinted at at least five complications. We have learned to ask simple questions and discover that they sometimes lead to important and surprising directions.

>**motion: it’s everywhere**<br>
><hr>
>Almost everything in physics boils down to: motion. (Even boiling.)

Whether it’s runners on a track, the cosmic rays piercing us all the time, orbiting planets, electrons in a wire, electromagnetic waves, quark wavefunctions inside a proton, electrons and holes in a semiconductor, or the stretching of spacetime itself. Everything is about "motion."

These first lessons on the physics of my grandparents’ generation will establish the language and tools that we’ll need in order to pursue the more exotic forms of motion and we’ll become skilled at manipulating concepts (and their attendant symbols) like velocity, kinetic energy, mass, momentum, and force. Each of these terms has a 16th to 19th century origin, but each has managed to keep up with the times as layer upon layer of subtlety is discovered about each of them as we dig deeper and discover more.

<mark>But at its most basic, our physics will be all about how to get from *here* to *there* and from *then* to *now*, and to be able to explain how that happened and predict what will come next.</mark>

## Speed in Modern Terms

To us, motion and its measure—speed—is a simple matter. Our cars and even devices on our wrists readily tell us how far we go, how long it takes us to get there, and the rate at which we do it. We can be penalized for traveling at rates that are...too enthusiastic. Speed, or its more sophisticated word-cousin, velocity, is so familiar to us that we hardly pay any attention to just how fundamental it is. Let’s start this very slowly (no pun intended) since some of our more sophisticated physics later will build on a strong underpinning of a few basic concepts. Speed is one such concept because it’s a blend of two even more fundamental concepts of space and time.

Speed is a rate. For example, 60 mph describes the change in our spatial position and how long it took to make that change. Like all rates, it’s a ratio with respect to time and we've already agreed:

$$
\text{speed} =\cfrac{\text{change of distance in space}}{\text{change of time}}\tag{1}\label{speedwords}
$$

Words are clumsy when we're trying to be precise. Let’s make this more compact by inserting customary symbols to get rid of the English words. Here are the rules of the use of motion in QS&BB:

-   We’ll limit ourselves almost exclusively to motion in one dimension
   in space.

-   We’ll use the symbol $v$ for speed (because customarily, we’ll speak
   of “velocity”…more about this below).

-   We’ll use the symbol $x$ for distance in one dimension, regardless
   of which direction it points.

-   We’ll use the symbol $t$ for time and almost always presume that we
   set our clocks so that the beginning time of any interval is
    $t_0=0$.

- Oh, and we’ll use the subscript $\text{ }_{0}$ to indicate the beginning of some time interval “$t_0$” or location “$x_0$” in a sequence of events.

-   We’ll use the Greek symbol Delta, $\Delta$ to mean “change of”…this
   will come up a lot.[^start]

   [^start]:So if class starts at 10:20 AM and it lasts for 80 minutes, we'd say that $t_0=$10:20 and $t=$11:40 and that the class duration is $\Delta t=$ 80 minutes

So our formula for calculating speed changes from the English sentence
in Eq. \eqref{speedwords} to a mathematical statement:

$$v = \frac{\Delta x}{\Delta t}\tag{2}\label{motion2}$$

We're going to revisit this simple equation over and over again.

## Calculating a Speed

Some traditional jargon and nomenclature. “Change” and “change-of” always means the difference between where you *are* as compared with where you *were*. Suppose I start out with $\\$150$ and my wife gives me $\\$50$. The *change in* my net worth is $\\$50$, right? We can represent this simple transaction as  

$$
\begin{align}
\Delta(\text{my wealth}) &= \text{where I ended up} - \text{where I started} \\
 &= \$150 - \$100=\$50
\end{align}
$$

which is the definition of our $\Delta$: always "the end minus the beginning," the final value of some quantity minus the initial value of that quantity.

Remember that we’re using the standard notation in which the “initial state” of any quantity will be decorated with a little “0” subscript, like $x_0$ here. The “final state” will usually have no subscript and just be $x$. So $\Delta x = x-x_0$. Get it?

> **sing along**<br><br>
Remember the rule. When you see the &#x270D; you should be copying what's between it and the victory sign, &#9996; . It's the path to your brain.

&#x270D;

So let's use this notation now and be a little more specific. If we agree that the speed is:

$$\begin{equation} v = \frac{\Delta x}{\Delta t} \nonumber \end{equation} $$

then the numerator and denominator -$\Delta$ notation really means:

$$ v = \frac{\Delta x}{\Delta t} = \frac{x - x_0}{t - t_0}.$$

&#9996;

Often, we'll pretend that we can start our clock at the beginning of some event and so we can usually just let $t_0=0$ and then the symbol $t$ just stands for the time interval as well as the ending time. You'll see.

When you go somewhere, or predict how long it will take to get from one place to another, you would instinctively use your average speed to calculate. You know how it goes. If the speed limit is 65 mph and you need to predict how long it will take you to go a long distance, you'd probably estimate that your average speed would be something like 50 mph, taking into account the slow trucks and rest stops.<br>

>**up north**
><hr>
> <br> *What's our average speed if we travel 300 miles in 6 hours?*
>
> Let's take a trip. Suppose we start driving from Detroit to above the Mackinaw Bridge.<br><br> We'll start around Comerica Park and stay on I-75 as in the figure
>
> ![north](../../assets/motion/figs/michiganABCD.png){:width="300px"}*Our trip to The Bridge (the letters will have a purpose below).*
>
> beginning at the nearest Comerica Park exit at the I75 50 mile marker then we’ll go all the way up, across the Mackinaw Bridge to Newberry, Michigan in the Northern Peninsula which we’ll say is marker 350.
>
> The change in our displacement is
>
> $$\Delta x = 350 - 50 = 300 \text{ miles}.$$
>
> Now, we can write the real velocity relationship:
>
> $$v = \frac{\Delta x}{\Delta t} = \frac{x - x_0}{t - t_0}.$$
>
> where I snuck in a “initial” decoration for the beginning time as well. If I start my clock ($t_0=0$) at mile marker 50 and stop it at marker 350, our average speed is:
>
> $$v = \frac{\Delta x}{\Delta t} = \frac{x - x_0}{t - t_0} = \frac{350 - 50}{6 - 0} = \frac{300}{6} = 50 \text{ mph}.$$

What if you stopped for lunch? That wouldn't be reflected in this calculation since average really only depends on the endpoints in space and in time. If we'd driven for 5 hours and eaten for 1, the average would be precisely what we calculated above, If you made the endpoints closer together then the "structure" of your trip would become more apparent and an average would represent more and more finely grained information. In fact what your speedometer does is calculate averages, but based on such a small time interval that the driver can treat the reading as instantaneous. I'll say a little more about what that means below.

## Diagramming Motion

Graphical representation of motion is particularly instructive and...therapeutic.  We can absorb the graph of some function in one visual gulp. A perfect example of such a representation is when you draw a route on a map. The map has “space axes” of east-west ($x$) and north-south ($y$) and in order to describe our route up north to a friend you might move your finger along the red line, of course with time implied as you point. So even though the line is a curve in just the *space* of North-East-South-West $(x,y)$ *time* is still there but hidden.

Let's do this and plot this boring trip as a function of time and of distance. First, I'll straight out our map and take those labels and put them approximately where they were on the map. Remember our story: we  started at the ball park (point A) at 50 mph and (impressively) held that speed constant for six hours. The graph of the speed is pretty simple, it's a constant function:

![too](../../assets/motion/figs/north1.png){:width="500px"}*Our speed graph in space.*

This is just telling that story using a picture: we drove at constant 50 mph from A to D over six hours. Six. long. hours. From our intuitive notion of a constant speed let's take Eq. \eqref{motion2} apart, rearrange some of the symbols, and find a surprise.

<div style="text-align:center"><video width="70%" controls>
  <source src="https://qstbb.pa.msu.edu/storage/QSBB_WebManuscript/motionVideo/constantSpeed.m4v" type="video/mp4"><source src="mov_bbb.ogg" type="video/ogg">
  Your browser does not support HTML5 video.
</video></div>

video for constant speed
{: .warning}

What we found in that calculation was that we would expect to see the distance increase at a constant rate in time for a steady speed. We know that because we found that the distance versus time relationship became the equation of a straight line.

>**algebra and geometry**<br>
><hr>
>I'm impressed by this sort of thing. Look what we did. We took our intuitive notion of a constant speed in an English paragraph, turned it into a simple algebraic equation, and then turned that into a graph that will give our location at any point along the way. This happens often---some algebra leads to a geometrical relation. In physics we tend to treat the plot on par with the equation as an "explanation."
>

So now we have a functional relationship that acts as a little calculating engine: you give me a time and a speed and your starting point, I'll reliably tell you your position when my clock reaches that time. The world can be pretty neat that way. Here it is:

$$x = x_0+<v>t$$

(where I've introduced the notation for "average" of a \<quantity\>). For this particular trip, we started when $t_0=0$ and at the ballpark entrance onto I75, we set our trip odometer to zero, so here $x_0=0$ as well. So we can now plot this function and get a graphical image of our distance at each point along the way.

![line](../../assets/motion/figs/north2.png){:width="500px"}*caption*

You might say, "I suspect we'll be near Grayling in about 3 hours." And if you'd been a resourceful, if not excruciatingly geeky traveler, you'd make the prediction accurate by looking at the plot you just made.

> **Wait.** Nobody does this.<br><br>
> **Glad you asked.** You mean I'm the only one?

The problem with this story is: how did we magically get to 50 mph? Of course we didn't, we accelerated and therein is another Galileo story and a fable.

# Acceleration, Galileo Style

Galileo is revered in physics for essentially creating two modern sciences (physics and astronomy), and for enunciating the principles of how science should work that are still relevant today. Very early on he recognized that the unnatural/natural motion notions of Aristotle were wrong. For example, Aristotle insisted that two objects made of the same material but of different weights would not hit the ground at the same time if dropped. The heavier one would be more “eager” to go to its natural place (the Earth’s center) than the light one. He explicitly linked an object's weight with the speed at which it would fall. Aristotle didn't do "quantitative" so his notion of "faster" was a proportional statement.

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;"> A battle has raged in the history of science community for decades about what experiments Galileo actually did (or whether he did any at all) and what experiments he just described as if he'd done them. This was compounded by the fact that one of his devoted followers---Vincenzo Viviani---clearly fictionalized some of the Galileo lore in a biography published after the grand man had died. Let's be clear: Galileo did not drop big objects from the top of the Leaning Tower of Pisa. He described such a demonstration, but got the answer wrong. Further, nobody ever claimed to have seen him do it, including Galileo himself. Myth, busted.</aside>

That the speed of a falling object increased the longer (further?) it  falls was clear. Galileo as a student realized that all one had to do was watch water drips from a roof...the distances that they travel in a given time are much longer near the ground than when they first leave the edge. So they are accelerating, but in what manner?

Galileo first started to think differently about motion when he was a professor at Pisa. That’s where he was supposed to have dropped a wooden and iron ball from the Leaning Tower, although we know that he couldn’t have done it the way the story went. His unpublished pamphlet on motion was a mixture of old language and his attempts at a new one, and so was not quite there yet.

His conclusions about falling objects were heavily influenced by his fascination with the pendulum. Let's leave that until after we work out what he found by experiment.

## Pisa To Padua

His salary as a mathematics and astronomy professor was abysmally low and he was clearly ready for a more lucrative position---plus nobody in Pisa was eager to have him around. So after three years, when he was offered a job at the University of Padua he took it and stayed for 18 years until 1610. Not only was his salary higher, the Venetian Republic was a much more independent region of Italy. Indeed, unlike Florence in Tuscany where connections to Rome and the Papacy were long-standing, Venice was often in the Papal Doghouse for its independent ways. Here Galileo became a popular professor, he created tools for military use that he was able to sell, including a manual. He settled into a common-law relationship with a woman with whom he had three children. But money was continued to be problematic and so he and Marina even took in students for tutoring and rental income into their crowded home.

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;">For a professor to remain single was not unusual and Galileo was a frequent visitor to Venice and its literary and art community. This was a sophisticated society with thousands of highly literate courtesans. While little is known about the early relationship between Galileo and Marina di Gamba, some have speculated that she might have been such a professional companion. Galileo stayed with her for almost a decade which might suggest that they were intellectually compatible—indeed, given his personality, it would have been surprising were he to spend time with someone not up to his conversational standard. In any case, Gamba moved to Padua to live with him where they had three children, two girls and a boy. (Birth records do not refer to a father.) When he went back to Florence in 1610, he took Livia and Virginia with him (aged 9 and 10) but left four year old Vincenzio with Gamba who remained in Padua and eventually married. He installed the girls in convents, where they would cost no dowry, and brought his son to Florence. Eventually, Vincenzo became a musician and was partially supported by the Pope, as a deference to Galileo. Virginia, later Sister Maria Celeste, relied on him for his influence in supporting her convent. She died in 1633, the year he entered house arrest as an old man. He was devastated</aside>

While Galileo was in Padua, he resumed some of his earlier experiments with moving objects. His original ideas were unformed but he reworked them as he shed his Aristotelian influences. At his home he had a workshop and eventually hired a toolmaker.

He determined to get to the bottom of falling (hee hee) and he wasn't the first. Some linked the speed of a falling object with its density. Others, like Leonardo da Vinci speculated from some fanciful geometry that an object would fall a particular distance in relation to the time interval. The figure below shows this. The left shows the distance that an object would fall in successive, equal time intervals as da Vinci imagined it. In the first unit of time - think, say a second, the object would fall 1 unit of distance. In the second unit of time, it would then fall 2 units of distance, in the third, three...and so on. That's a notion of an object accelerating, but not a constant acceleration.

![fall](../../assets/motion/figs/freefallGdV.png){:width="500px"}*The left group shows a ruler with equal markings and bold marks where a falling ball would be after the equal time intervals on the left---as described by daVinci. On the right is Galileo's results. The arrows are described in the text.*

There was another suggestion that came from the 1300s that in each successive unit of time the speed of an object would increase according to the _odd integers_!

So, in time intervals 1, 2, 3 seconds, the speed would have values 1, 3, 5 units. Galileo set out to find the answer, and found it to be the latter: the odd units. This is shown on the right side of the figure. <mark>That same 14th century argument demonstrated geometrically that this progression of the odd integers would stem from a <em>constant acceleration</em>.</mark>  Look at the lines drawn in on the right of this figure. Notice that the first interval of time leads to 1 unit of fallen distance. The second interval is 3 units (remember, the odd integers), the fourth...of course, 5 units. Now add them up for the total distance fallen as time increases: the first unit of time, 1. The second unit of time $1+3=4$. The third unit of time, $1+3+5=9$, and so on. 1, 4, 9... are the perfect squares of the time intervals, 1, 2, 3... Seeing falling objects that increased their total distance by the perfect squares would be the smoking gun for evidence of a constant acceleration.

Why not just measure it? Well, things fall fast! In the early 17th century precision time-keeping really didn't exist. He was near Venice, one of the oldest and most celebrated striking-clocks in history, but to measure times as fast as those of a falling body? Not possible. But this guy was clever.

## What Did He Do?

Galileo tricked Nature...in 1604 he found a way to dilute gravity so that he could make timing measurements using contemporary tools. Instead of dropping a ball, he let it roll down an incline. He reasoned that whatever pull a ball felt in free-fall would still govern the reduced acceleration in a slow descent down an incline. He found that inclines of only two or three degrees were ideal. The figure below shows his setup and his results.

![ramp](../../assets/motion/figs/galileoPlane.png){:width="500px"}*A ball "falling" down an incline.*

Galileo was good with his hands, and appreciating that he needed to reduce the effects of friction and other extra impediments to determining the real rules, he built inclines with finely machined grooves to minimize the effects of friction and then made elaborate schemes to measure the time that it took for an object to “fall” as it rolled slowly down the incline. He needed a clock, so he used his pulse. When that wasn’t sufficiently regular, he hired a string quartet to play at an even meter. He then invented a “water clock” that slowly dripped at a regular rate and it was with that, that he was able to see how far a ball would roll during each “tick” of his water clock.

How do we know that this was a real measurement and not another thought-experiment? Because he told us. Galileo kept careful records of his experiments and these have been preserved.

This amazing figure

![note](../../assets/motion/figs/galileoNotes.png){:width="600px"}*Galileo's notebook from 1604. His work has been digitized, translated, and annotated. This page is from [folio107](http://www.mpiwg-berlin.mpg.de/Galileo_Prototype/HTML/F107_V/F107_V.HTM).*

shows the aha! moment in one of his pages where he’s taking his measurements, scribbling around the sheet, and keeping his records in the upper left hand corner. The preeminent Galileo scholar, the late Stillman Drake from the University of Minnesota studied these notebooks and found something intriguing.  Notice that the numbers 1 through 8 are clearly visible in the middle column in the inset. The numbers on the right are the distances he measured down the plane, and are a result of some of the arithmetic on the sheet. But the numbers in the left hand column? Drake noticed on this particular page that the ink used in the left column was different from the ink in the actual data-taking on that page. In fact that ink was consistent with pages that came from entries many days later. Look carefully at those numbers...they are 1, 4, 9, 16, 25, 36, 49, 64.

>**a most important moment**
><hr>
>The presumption is that Galileo had taken the data, then pondered the results and realized later that his measurements fit the time-squared rule and came back later to the page to add them in. Imagine what his emotional state must have been when he realized what he’d done! He's demonstrated that the acceleration of a falling body is constant. I think this is one of the most important documents in the history of science.

## Little $g$

Let's do what we almost always do when confronted with data: plot it. I can just make out the numbers in his manuscript. The units for both time and distance are a little unusual, so we'll leave them without dimensions.

![num](../../assets/motion/figs/galileoPlot.png){:width="500px"}*caption*

This is a familiar shape and the squares in the data above give us the clue that this is the shape of a parabola, and it's a pretty good one. The curve is not drawn through the points, but rather is a fit to the functional form of a parabola. So we could write the equation of this curve as

$$x(t)=\text{constant  }\times t^2$$

The constant comes from measurement and in modern units we write:

$$x = \cfrac{1}{2}gt^2$$

where we give this special, constant acceleration a name, the “acceleration of gravity,” $g$, or “little g” which is roughly 32 ft/sec/sec, or 9.8 m/s$^2$ which was first measured by Isaac Newton a generation later using pendulums.

>**little g**
><hr>
>Objects near the earth's surface fall with essentially constant acceleration.

He then made yet another important leap: In practice, a heavier object would hit the ground slightly before a lighter one, but he correctly reasoned that this was because the effect of the resistance of the air would be a larger retarding force on the little ball than on the heavier one. How did he come to that conclusion? Two ways.

First, he out-Aristotled Aristotle by arguing logically. Suppose you took two objects, one more massive than the other, and tied them together. A strict interpretation of Aristotle would say that the lighter object would retard the motion of the pair since it would have more of the property of "lightness." But the same reading of The Philosopher would argue that the heavier one would make the pair go faster. You can't have it both ways and so Galileo reasoned that Aristotle's argument was logically inconsistent. But he also reasoned from another phenomenon. Let's take a quick side-trip.

## The Pendulum

A pendulum is a trivial toy, yet it encompasses many key physics ideas about motion and force. Galileo, Huygens, and Newton each made many pendulums and did extensive experiments with them. Because of its immediate simplicity, quantitative measurements are easily done with modest tools. It will come up over and over! This figure is a picture of a simple pendulum which I’ll refer to periodically over the next few chapters.

<figure><img src="../../assets/motion/figs/pendulum.png" alt=" - " width="100%" /><figcaption>caption</figcaption></figure>

These are all observations that Galileo made about pendulums. In (a) the little pendulum bob makes a to-and-fro motion from A to B and then back to A and the same thing happens in figure (b). Galileo found that the time to complete a full period (from A-B-A, and from C-D-C) would be the same for (a) as it is for (b).[^pend]  This is called the isochronous (equal time) behavior of pendulums. It doesn't matter how far up you start the pendulum, the time it takes is the same for all. He found that the period of a pendulum depends only on the length of the cord.

 [^pend]: This is strictly true for only small angles which was not understood for 50 years.

The next thing that he found was not quite the case, but here he was again, very clever. Look at (b) which has some additional markings. The height that the bob starts from at C, $y_C$, is the same as the height that the pendulum goes to at D, namely $y_C=y_D$. Furthermore, this height is obtained back and forth as the pendulum repeats its motion.

But real pendulums don't do this exactly---they slow down.

This is an example of the most important idea that Galileo left for us, even more important than some of his discovered facts about Nature:

>**the real-rules of Nature are hidden**<br>
><hr>   
> Galileo decided that the regularities of Nature were ideal and hidden from actual behavior. We can get close, but not exactly there. An ideal pendulum would repeat forever, always coming back to those original heights and it's friction in the pin and air resistance that modify that perfect behavior. **The goal of natural philosophy (our "science") is not to describe what we observe in real life, but rather to uncover those hidden regularities** and then explain the corrupted behavior that we observer as due to small influences like friction. Without this new motivation, physics is impossible.

Every event we observe would be slightly different. But rather than dwell on the differences, <mark>Galileo was the first to decide that there was *something that was the same in every event*.</mark>

Galileo studied this return-to-the-source phenomenon by sticking a peg in the way of the string causing the bob to quickly rise...back to that same level as shown in figure (c).

Finally, here's one more important discovery. Figures (d) and (e) are meant to represent the comparison of two pendulums for which the bobs are either or both different masses or different materials. Through experiment he found that they behave identically. Nature doesn't care if the big bob is heavier like iron and the other is lighter like wood: they have the same periods and behave the same regardless of the Nature of the bobs.

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;"> Galileo found that the period depends only on the length of the cord. Newton went further and measured $g$ using pendulums, deriving the period mathematically from his mechanics.</aside>

### Back to falling bodies

It's this extrapolation from pendulum motion to falling bodies that led him to decide that a falling body accelerates the same regardless of its size, material, or weight.

<mark>There are two really important ideas here.</mark>  First, again he's assuming that the true rules of motion are ideal and hidden from us in real life. Second, he explains the observational fact that a heavier object when dropped _will_ fall to the ground faster than a light object. Your eyes deceive you! That is, if you expect your raw, naive observation to tell you the underlying rules of motion. He surmised that the lighter object is much more affected by air resistance than a heavier one. Even if an object was the same material, but different shapes---they should land at the same time, but in real life the air would slow down the larger of the two.
<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;">You can test this yourself. Take two identical pieces of paper, crumple one up into a ball and drop them both. What happens?</aside>

He never in his life---nor have you or I---ever seen two different objects fall in the presence of gravity in exactly the way that Galileo insisted was the underlying rule. Humankind had to go to the moon in order to test this in the complete absence of any air:

<figure>
<div style="text-align:center"><video width="70%" controls>
  <source src="../../assets/motion/figs/moon.mp4" type="video/mp4"><source src="mov_bbb.ogg" type="video/ogg">
  Your browser does not support HTML5 video.
</video></div>
<figcaption>In 1971 towards the end of his last moon-walk, Commander David Scott dropped a hammer and a feather in order to demonstrate (test?) Galileo's assertion about free-fall. Scott was an engineering student at the University of Michigan for one year (and was on the swim team) when he transferred to West Point. He graduated with such high grades that he was able to pick which service to join and chose the Air Force where he became a test pilot. Apollo 15 was the fourth moon landing and Scott's third space mission.</figcaption></figure><br>

Notice that he's connected pendulum motion with free-fall, not an obvious thing to do. *But he went further.* In an ingenuous blending of pendulum and inclined plane motion, he discovered Newton's First Law of Motion, 60 years before Newton did. :) This figure tells that story:

<figure><img src="../../assets/motion/figs/forever.png" alt=" - " width="100%" /><figcaption>caption</figcaption></figure>

In the top figure, a ball rolling down an inclined plane gets to the bottom and rolls up the adjacent plane to B which is at the same height as A. In the next figure the second plane is shallower, but the ball still makes it back to its new B...which is at the same height. The next figure, the same thing happens. Galileo then says what if the adjacent incline is not an incline at all, but just a flat surface---his conclusion was that the ball would continue in a straight line forever. [^forever]

[^forever]: Actually, here he was confused. His "straight line" would have followed the curvature of the earth's surface. So not Newton's "straight line."

Notice that this conclusion is totally contra-Aristotle! There's no pushing involved in this final motion. Once it’s started, it goes. Notice how far behind Aristotle looks in Galileo’s rear view mirror! He’s not worried about natural or unnatural motion and he’s not concerned himself with _why_ the motion continues. Rather he’s asking different questions...*How* questions rather than *Why* questions. Aristotle’s students would start with a philosophical prejudice and interpret what they saw in accordance with that philosophical system. Why did something in Nature happen? Aristotle's writings would provide the answer, regardless of the contorsions required to make it fit. The authority of Aristotle functioned much like legal precedent functions in a courtroom: you explain according to textual authority. Nope. Not our Galileo, not in our science.

Galileo threw all of that aside and observed Nature with very little bias or preconceived notions. So if you release a ball in any of our three examples---free fall, pendulum, and inclined planes---*where would it go?* is his question. Not, *why* would it go. He’d set up the circumstance and he'd observe it---no Aristotelian would do an experiment. They would think about it in the specific context of the philosophy and passively observe.

Now he’s doing physics. He was after Nature’s “real rules” which are hidden behind the apparent motion, affected by the air. He was exploring what’s the same about falling objects, not what was different about them. <mark>Aristotle has left the building.</mark>

## Air Resistance

Little $g$ is a large acceleration, but raindrops don’t usually bruise us and hail stones don’t usually kill. Were there not for air resistance, nice spring showers would be dangerous as rain drops fall a long way! It turns out that things dropped from high up reach a speed in which the viscous drag of air friction pushes back with the same force that the Earth pulls, causing a falling object to reach equilibrium. The result is that the speed of falling becomes constant to what’s now called the Terminal Velocity, which depends on an object’s size.

For example, a regulation major league baseball will reach terminal velocity in about two and a half seconds after falling about 100 ft. At that point, its speed will be just about 60 mph and will stay at that value. For reference, the “Green Monster” left field wall in Fenway Park is about 40 feet (11 m) high, so you can see that high fly balls would be high enough to reach terminal velocity on their way down.

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;">There have been stunts performed with baseballs dropped from the Washington Monument, skyscrapers, and balloons for players to catch. The speed that a baseball would achieve is not much more than that experienced by a catcher on a high school baseball team. However, famously a professional catcher knocked himself out miss- ing a ball dropped from a blimp.</aside>

While Galileo was on the faculty at Padua, he did other experiments with motion which lay dormant until in 1638 he wrote the second of his great books, _Discourses and Mathematical Demonstrations Relating to Two New Sciences_. He finished this work while in house arrest outside of Florence as an old, sick man. How he got into trouble is a story that we’ll leave for our discussion of early astronomy.

# Acceleration, In Everyday Terms

So far we've treated acceleration descriptively: it's when velocity increases in successive intervals of time. Let's put this on a more firm footing by defining it just like we defined velocity, only different:

$$a = \frac{\Delta v}{\Delta t}=\frac{v-v_0}{t-t_0}.$$

Remember our trip up north? Let's take our first version and make it a little more realistic. In order to travel at that constant 50 mph...we had to get there. That is, we had to accelerate. Let's describe that in symbols and in graphs.

video to work out acceleration
{: .warning}

>**starting up, going, and arriving**
><hr>
> <br> *Plot the distance versus time for our trip where we assume that we reach a new cruising speed of 60 mph after a half hour (speeding up between A and B) and start to slow down (traffic? enormous mosquitos?) with 90 minutes to go.*<br><br>
>
> Remember, A is where we start, between B and C we are able to maintain a steady 60 mph, and D is where we stop.<br><br>
>
> ![north2](../../assets/motion/figs/michiganABCD.png){:width="300px"}*Our trip to Canada, more detail.*
>
>Now we're assuming that the acceleration from A to B is constant and so that makes things easy since:
>
> $$a=\frac{v-v_0}{t-t_0} = \frac{60-0}{0.5-0} = 120$$
>
> since we started from a stop ($v_0=0$) and we started our clock when we started to move ($t_0=0$). I've not put in units, so we need to think about that. The units of velocity are miles per hour and those of acceleration then divide that by time. So the units here are miles per hour per hour, or miles/hour$^2$. A little unusual, but it makes sense.
>

<div style="text-align:center">
<video width="90%" controls>
  <source src="https://qstbb.pa.msu.edu/storage/QSBB_WebManuscript/Introduction/SolvingNewton1.m4v" type="video/mp4">
  <source src="mov_bbb.ogg" type="video/ogg">
  Your browser does not support HTML5 video.
</video>
</div>

> So our progress between B and C plotted against time --- we'd say, distance plotted as "a function of time"--- is this simple graph:
    <figure><img src="../../assets/motion/figs/northvversust.png" alt=" - " width="800%" /><figcaption>Velocity versus time for the whole trip.</figcaption></figure></p>
>

Are you squeezed to the back of your seat?

That initial (constant) acceleration from 0 to 60 mph took 30 minutes, 0.5 hours. Was that a scary acceleration or leisurely?<br><br>

One way to scale the human effects of acceleration is to think in terms of factors of little g. One free-fall acceleration is 1 gee, 32 ft/s/s. But we worked in mph and so from the slope of the acceleration line between A and B, we found $a(AB)=120$mi/h/h. How many gees is that? As a point of reference, shuttle astronauts would experience 3 gee on liftoff, Gemini-era Titan rocket folks would experience 7.25 gee. Neither you nor I have experienced anything like these accelerations (unless one of you is an astronaut or fighter pilot!).

Here's a little conversion engine for our accelerations. Was this space-program-worthy acceleration?<br><br>

<input id="c" onkeyup="convert('C')"> m/h/h <input id="f" onkeyup="convert('F')"> ft/s/s

So, notsomuch. You should have calculated 0.0015 gee.[^gee1]

[^gee1]: Don't forget to divide by 32 ft/s/s!

What about the distance traveled as a function of time? From our discusion of the constant little-g acceleration, we know that the distance will be a quadratic function of time during the period of acceleration and uniformly increasing for the period where the velocity is constant. So between A and B and then between C and D we would have a change that's positive like $t^2$ and negative (slowing down, or _decelerating_) between C and D and linearly increasing between B and C.

![north3](../../assets/motion/figs/northxversust.png){:width="500px"}*Our distance traveled as a function of time.*

This leads us to a little detail. We know the distance at any time. We know the acceleration at any time. What's the velocity at any time? We've defined velocity as an average

$$v = \frac{x-x_0}{t-t_0}$$

which is not at a particular time, but rather between two times. _A particular time_ means at a precise time where the interval would be zero. That blows up the denominator and Nature doesn't do infinity!

So let's take a small excursion to explain this. Think of this as a cultural moment and not the kind of explanation we'll need to do in the future. (It's sneaking up on calculus.)

video for velocity limit
{: .warning}

<figure><div style="text-align:center"><video width="70%" controls>
<source src="../../assets/motion/figs/moon.mp4" type="video/mp4"><source src="mov_bbb.ogg" type="video/ogg"></video></div><figcaption><em>A cheap explanation of instantaneous velocity.</em></figcaption></figure>

Let’s take a bike ride.

## Graphical Kinematics

Let’s work out an extended example with realistic numbers. Follow along with me because if you become comfortable with this, what follows will be smooth sailing. Try to be comfortable with the graphical solution to questions and how it short-cuts an algebraic approach.

Let’s think about a cyclist moving at a constant speed. These two pictures

![velthree](../../assets/motion/figs/constantVelocity_2.png){:width="500px"}*caption*

describe all that you need to know about an object moving at a constant 4 meters per second (about 9 mph—a sprinter’s speed, or a relatively slow cyclist’s speed). Here we take the initial position to be zero (it could be our house). And, we take the initial time as zero (it could be when we leave).

&#x270D;

>**biking**
><hr>
> *How far do you travel if you bike at a constant 4 m/s for 6 seconds?*<br><br>
>
>In the first second from the right plot I see that my speed is 4 m/s and that I traveled about 4 m (left plot). In the next second, my speed is *still* 4 m/s (right plot) and I travel another 4 m (left plot). The *slope* of the quantity $x$ plotted as a function of time $t$ is the constant $\Delta x /\Delta t$ which I pointed out is the *slope* of the curve. That’s easy since the speed is constant. We can look at the graph >at $t=6$ s and read about 24 meters. <br><br>Or, equivalently, we could use the formula and calculate:
>
> $$\begin{aligned}
 v &= \frac{x}{t}  \nonumber \\
x &= vt  \\
x &= (4 \mbox{ m/s})(6\mbox{ s}) = 24 \mbox{ m.} \end{aligned}
>$$
>

&#9996;

Now, suppose I speed up to pass the cyclist in front of me. My speed increases and I cover ground at a faster rate: during each time interval, I travel more than the time before. Of course I’m accelerating if I’m going faster during each interval (“decelerating,” if I’m going slower). In either case, the state of my motion *is* changing from my previously steady speed.

This figure shows the predictive power of kinematics when applied to *constantly* accelerated motion.

![ ](../../assets/motion/figs/constantAcceleration.png){:width="500px"}*caption*

The curve on the right shows a *fixed* *acceleration* of 2 m/s$^{2}$. If this were a car, it’s like your foot is on the accelerator in order to maintain a constant force and hence, a constant acceleration on your bike, you need to overcome friction and wind, so maintaining a constant force on the pavement is hard work. This constant acceleration means that the velocity is changing at a constant rate—proportional to time—and that’s shown in the middle plot. So, at 6 seconds, your acceleration is 2 m/s$^{2}$, and your velocity or speed has increased to 12 m/s from the start. In the mean time the distance you traveled is going up faster: as we learned from Galileo, it increases proportionally to the square of the time and this is shown in the left hand plot. If you started from rest, at $x=0$, by the time 3 seconds have passed, you’ve traveled 9 meters, and by a total of 6 seconds, you’ve gone 36 meters, so your distance intervals are increasing with each increment of time.

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;">As we’ll see, if the state of my motion is changing, there’s a force: which I’ve applied by pumping my legs faster and faster, which is transmitted as a push on the road (earth) through the rubber tires. </aside>

Finally, thought of geometrically, the slope of the middle plot is constant—the change of speed with respect to time increases at a steady rate, the value of the constant acceleration. But, now the slope of the left hand plot of distance changing in time is *not* constant—at each successive time interval, it’s steeper and that’s reflected in the fact that the middle plot value changes at each time and so *instantaneously* (the tangent, if you want to be fancy), the speed is different and so the distance increases.

So for the constant acceleration (right hand plot, $a=$ constant), which results in a steadily (linear, $v \propto t$) increasing speed (middle plot), the changing distance covered per unit time increases a lot: the shape of that curve (right plot) is a parabola, $x \propto t^2$. As has been known since the 14th century this parabolic, or quadratic, increase in distance with respect to time is the smoking gun for constant accelerated motion.

We would then write for all of these situations:

$$
\begin{align}
x &=\frac{1}{2}at^2 \\
v &= at \\
\end{align}
$$

The second equation works at a particular time since the acceleration is constant, that 2 m/s$^{2}$. So the same equations for Galileo.

Now go back to our trip up north and  we can see that those constantly accelerated regions are parabolas, turned down for slowing down between C and D, and turned up for constantly accelerating between A and B.

# Special Kinds of Acceleration

We can categorize acceleration into three separate categories with what
we now know.

## Zero Acceleration

No acceleration indicates a an object maintains a constant velocity.

## Positive and Negative Acceleration

Positive and Negative accelerations mean very different things here and we’ll illustrate this with a simple pair of examples. When you leave the city limits, your speed goes from 35 mph to 55 mph, so the numerator in the definition of acceleration in Eq. [acceleration] $$\Delta v = v - v_0 = 55 - 35 = +20 \text{ mph}$$ and this would be a positive acceleration (when you divide by the time it takes), or just “accelerating.” But when you come into town from the highway, your speed goes from 55 mph to 35 mph and the numerator in the acceleration equation $$\Delta v = 35 -50 = -20 \text{ mph}$$ would be a *negative* acceleration, which is called a *deceleration*. So acceleration is negative or positive by virtue of whether the object is slowing down or speeding up.

## Varying Acceleration

When you accelerate in your car, you probably press on the accelerator pedal more and more. If you held it constant and ignored wind resistance, you'd accelerate at a constant rate. But if you press harder and harder, you're varying the acceleration...a non-constant acceleration. This is a more complex problem mathematically, so we'll not go there. But it's  a very common occurrence.

Cars are not the only place where we encounter non-constant accelerated motion. How about running? A sprinter comes out of the blocks with a very high change of speed, and so a very high acceleration. As she gets into her stride and become more erect, her effort must fight against wind resistance and besides, her internal quick expenditure of energy would be hard to maintain, so there’s a *reduction* of acceleration. Note this doesn’t mean a reduction in velocity, just that the velocity increases at a slower rate as the race goes on. Nor does it mean a deceleration...she’s still going faster, just at a lesser rate than before.

![madden](../../assets/motion/figs/madden.png){:width="500px"}*From Madden Football _11_ modeling of a halfback's (non-constant) acceleration.*

# The Equations of Constant Acceleration

Acceleration at $g$ is called…well, “gees.” And “pulling gees” is a measure of acceleration that fighter pilots must contend with: in order to not black out, humans can tolerate accelerations up to around 6 $g$’s, or $6\times 9.8$ m/s$^2= $ about 60 m/s$^2.$ That’s moving right along as you will see from the Porsche-experience below.

The plots for motion had their origins with Galileo, but their algebraic form waited for the 17th and 18th Centuries to become standard. Our formulas so far can be summarized here:

$$
\begin{align}
x_{ave} &= \frac{\Delta x}{\Delta t} = \;<x> \\
v   &= v_0 + at \\
v_{ave} &= \frac{(v+v_0)}{2}  =  \;<v> \\
x   &= x_0 + v_0 t + \frac{1}{2} at^2 \\
 v^2   &= v_0^2 + 2ax
\end{align}
 $$

Obviously, if the motion starts from rest, then the initial velocity is zero ($v_0=0$) and we can often easily define our coordinate system so that the initial starting point is set to zero ($x_0 = 0$).

Let’s work out what the acceleration would be for cars that you may or may not drive.

If you own, say, a Mitsubishi Mirage ES, it will take you around 12 seconds to get to sixty. If you own a Porsche 911 Carrera S, it will take you closer to 4 seconds.

&#x270D;

>**the slow ride**
><hr>
> *What’s the acceleration of the Mitsubishi in m/s$^2$?*<br><br>
>
>From the above equations, we can see that if we start from rest, then $v_0 = 0$ and we can calculate:
>
>$$
\begin{aligned}
 v_M = a_M t_M \\
 a_M = \frac{v_M}{t_M} \end{aligned}
>$$
>But we need metric units, so we can refer to the mph-mps converter
><input id="mph" onkeyup="convert('MH')"> mph <input id="mps" onkeyup="convert('MS')"> m/s
>
>and see that 60 mph is just about 26 m/s. So for 12 seconds, we get
>
>$$
\begin{aligned}
 a_M &= \frac{v_M}{t_M} \\
 a_M &= \frac{26}{12}  \approx 2
\text{ m/s}^2 \end{aligned}
>$$
>
>

&#9996;


Not exactly like falling off a log...or falling off of anything for that matter, since it’s almost 5 times less acceleration than 1 $g$! If you black out while speeding up with your Mitsubishi, it’s not because of acceleration.

<div class="graydeal">
<h2like>you do it: the fast ride</h2like><br><br><hr>
<h3like>What’s the acceleration of a Porsche 911 Carrera S for the same 0-60 mph trip?<br><br></h3like>
<p></p>
</div>

These two states of motion—constant velocity and non-constant velocity—are very different. We’ll see in our discussion of Relativity just how different, but let me let the cat out of the bag right here. Have you ever been in a train or a car where you’re relatively enclosed and can only see a car or train next to you and not the earth? If the adjacent vehicle starts to move you can be suddenly confused: who moved? You might actually not know! I find that unsettling, and my brain quickly tries to figure it out. This is an inherent feature of constant velocity motion: there is no “right” answer as the same unsettled feeling would be felt by a passenger on the other train. Both are equivalent situations relative to one another. There. I’ve said the word “relative” and you now have the hint of only a part of what’s interesting about Einstein’s theory of *relativity*. We'll see that Galileo made the first big leap in this whole question of "relative motion."

# Going In the Right Direction!

Now we need to add one more piece to the modern story. As we saw in the Tools lesson, distances—displacements—are vector quantities. Because distance is in the definition of velocity, and since distance is a vector, so is velocity. Since velocity is a vector and acceleration is defined in terms of it? Yes, acceleration is a vector too.

## Velocity Is a Vector

Here’s our first physics-vector. I’ve been loose with the words speed and velocity. In fact, there’s a difference: velocity is a vector, $\vec{v}$, and so it includes a magnitude and a direction, and the magnitude of velocity is the speed. Now the definition should really be:

$$\vec{v} = \frac{\Delta \vec{x}}{\Delta t}$$

implicitly included distance ($\vec{x}$) as a vector quantity, but not time. North and east are different directions and $\vec{x}$ makes that clear. Like mass, temperature, and many other quantities, time is not a vector. At least, not yet!



So 60 mph east is not the same velocity as 60 mph north. The speeds are the same, but the velocities are different. And, certainly if you’re trying to go north, you don’t want to deploy a *velocity* that points east. So both the magnitude (speed, here) and the direction are required to specify a velocity. We simply draw an arrow, the direction of which points in the direction of travel and the length of which is defined by some scale of speed magnitudes.

Now when you’re walking I want for you to invent your own speed scale—how many inches equals 1 mph of speed— and then imagine this arrow sticking out of your chest. As you speed up, the arrow gets longer and as you slow down, the arrow shrinks. If you turn left, the arrow turns with you. Everywhere you go, you imagine your very own velocity arrow preceding you. You should also imagine arrows coming out of everyone you see, people on bicycles would have longer arrows and cars would have even longer ones. When they come to a stop sign? The arrow shrinks as you decelerate and blinks out of sight. Keep this in mind as we move on to those length-changing arrows.

## Acceleration Is a Vector

Since velocity is a vector and acceleration is defined in terms of velocity, it too is a vector: $$\vec{a} = \frac{\Delta \vec{v}}{\Delta t}.$$ While the little arrow that represents your personal velocity is always point out in front of you, its direction seems rather arbitrary. It goes where you go, but there’s nothing special about the direction. But that’s not really the case since our movement is inside of a coordinate system of streets, sidewalks, hallways, etc. and they all have relative directions. So let’s for a minute remember the obvious...if we take our coordinate system to be (arbitrarily) that to go east is to go in a positive direction and west, a negative direction then you could describe your vector that way. If you’re walking east, then you could say your velocity is 2 mph, east, or you could say that your velocity is +2 mph. If you’re walking to the west, your velocity would be -2 mph. The direction and the sign are mingled. Because we will work in one dimension most of the time, this dual-role for a sign will matter but hopefully be pretty easy.

This is important as we consider the direction of an acceleration. Suppose your speed is 60 mph and after a certain time—let’s say 2 hours—your speed has increased to 70 mph. Remembering our ordering in the $\Delta$ notation of ( now - before), then then the magnitude of your acceleration would be: $$a = \frac{\Delta v}{\Delta t} = \frac{70-60}{2} = 5 \text{ miles per hour}^2$$ Now what if your original speed is reduced because you applied the brakes from 70 mph to 50 mph. Then we’d have: $$a = \frac{\Delta v}{\Delta t} = \frac{50-70}{2} = -10 \text{ miles per hour}^2$$ What are we to make of that negative sign? Of course it means we’re slowing down, and we learned that the term for that is deceleration. But that pesky sign change between accelerate and decelerate is again related to our coordinate system. If we continue to take east as positive, and have both of our circumstances—the acceleration to 70 mph and the deceleration from 70 mph—be easterly motion, then that algebraic negative sign that came from the calculation plays a geometrical role.

Now you have two vectors point out of your car’s hood. First we have the velocity vector, which is always positive as long as we’re traveling east, albeit getting longer in the one case and shorter in the other. Then we have also an acceleration vector that points to the east when we accelerate (corresponding to the change of the speed being positive) but points west when we decelerate. That’s what the negative sign does, it changes the direction of the acceleration vector. Let’s see how this works.

### What Goes Up, Must Come Down

Armed with Galileo’s discovery and our notion of vectors, the acceleration felt by all falling objects near the Earth is constant, we can look at some examples. Let’s drop something from the Leaning Tower, in honor of fictional accounts of famous scientists.

Mr. Google tells me that the height of the Leaning Tower is 183 ft. By now, you know how to convert that to meters and it’s 57 m. The first thing to realize is that a baseball dropped from the Leaning Tower at this height would likely reach terminal velocity. But let’s ignore that for a moment—we will pretend that the atmosphere doesn’t exist—and look at Fig. [tower] for the arrangement.

<span>That Leaning Tower</span>

Drop an apple from the Leaning Tower of Pisa, all 57 meters.

-   Draw a picture that shows the rock on its way down twice...near the
   top and near the ground: draw a representation of the distance
    vector, the velocity vector, and the acceleration vector on
    the rock.

-   How fast is a rock moving just before it hits the ground?

-   How long does it take to hit the ground?

[tower1]

Always draw a picture. We’ll take the positive $x$ axis to be pointing down, in the direction of $\vec{g}$ and the direction of $v$, so both are positive and increasing in magnitude. Figure [tower] shows the situation and the various vectors. The distance axis is on the left side. On the right side of the figure are the kinematical vectors. The velocity vector gets longer as the apple falls and the acceleration vector stays the same. Notice that there is an acceleration at the top.

We can use various of the equations from the set in
Eqs. [kinematicseq]. To find the time, for example, we can use
$    x = x_0 + v_0t + \frac{1}{2} at^2$. We defined our coordinate system so
that $x_0=0$ at the top of the tower. And since it’s dropped from rest
without being thrown down, $v_0=0$. And we can then calculate the time
when $x=57$ m: $$\begin{aligned}
x       &   =  \frac{1}{2}  gt^2 \nonumber \\
2x/g &= t^2 \text{ so }
t = \sqrt{2x/g} = \sqrt{\frac{(2)(57)}{9.8}} = 3.4\text{ s}\end{aligned}$$

In order to calculate the speed at the bottom, we could use a couple of equations. We could use:

$$\begin{aligned}
v^2 &= v\_0^2 + 2ax = 0 + 2(9.8)(57) = 1117 \\
v &= \sqrt{1117}=33.4\text{ m/s}\end{aligned}$$

<span>tower</span><span>tower</span>

Now, you do it. Closer to home.

<span>apple1qr.png</span><span><span>motion</span>/apple1</span><span>Instead
of dropping something from the Leaning Tower, drop an apple from a table
to the floor, 1 meter down. What’s its speed just before it hits?
Calculate it in m/s and pretend that $g=10$ m/s$^2$...it’s
close!</span><span>4in</span><span>applemotion</span><span>0.5in</span><span>Apple
Motion</span>

In fact, while the above illustrations are elementary, they lead us to practical and interesting questions. For example, suppose I throw a ball straight up. We could analyze the velocity vector on the way up and the way down and the acceleration vector during the same trip. Galileo’s assertion that the acceleration is constant for all objects, we interpret as the acceleration vector of constant length pointing *down* throughout the path, up and down. What about at the very top? Is it accelerating? Yes. Is it moving? No. One of the biggest indignities that Aristotle’s motion suffered was trying to explain projectile motion. Galileo has that covered too.

# Projectiles

Although we’ve been dealing with 1-dimensional motion, Galileo wasn’t done when he figured out that everything falls at the same, constant acceleration of gravity. He also tackled the other problem that Aristotle messed up: throwing something. With an understanding that objects would happily move at a constant speed without being pushed (his two inclined planes) and that objects fall towards Earth with a common acceleration, he had the genius idea to embed these two different motions together into the motion of a single, thrown object. Let’s follow his experiment by looking at his notes in Fig. [drake2].

>**projectiles, Aristotle’s way**<br>
> <hr>
>Where Aristotle got himself into big trouble was with projectiles, like a thrown spear. His philosophical system came before explanation so he had to do an embarrassing dance to explain that when a rock was thrown the continuous “push” that he insisted was needed came from the displaced air rushing around behind the rock and pushing it forwards. Seriously. Everyone knew that this was nonsense. How can you throw a pointed spear sharp end first and the blunt end first? His authority was absolute, and organization of the first medieval universities with Philosophers and Theologians at the top guaranteed that natural science was taught by them.  Mathematicians and astronomers had supporting roles that were aimed at more mundane activities like casting horoscopes and designing military weaponry and fortifications.

What you see are various measurements of rolling a ball off the surface of a table and marking where it lands according to how fast it was going. How did he repeat measurements so that each attempt would be the same speed upon lift-off? He rolled them from an inclined plane where he could dial-up the speed he wanted by how far up the plane he let go of the ball as shown in Fig.\~[projectiletable]. Clever, no? So let’s think like he did. If the speed of the ball at B is $v\_x$, then what’s the speed of the ball just at the edge of the table, C? $v\_x$. Now the ball acquires two separate motions that are combined: the ball *continues* to have the horizontal speed, $v\_x$. But as it falls, it starts to acquire a *new vertical speed*, accelerated down by $g$. The two motions are separate, but together! So throughout the trajectory, the ball’s *horizontal speed remains* $v\_x$. Nothing has happened to change that. The ball’s *vertical speed increases* as the ball “falls" along this curved path.

Now here’s the neat thing. Suppose at the same point where the ball leaves the table, another ball is allowed to just drop from that point, say at point C in Fig. [projectiletable] so that it falls (under the influence of gravity!) to point E. This one has only one kind of motion, vertical and accelerated. In fact, it’s accelerated by the same amount as the first one and from the same vertical height, at the same time. So which one reaches the floor first? They both reach the floor at the same time.

This bundling up of two separate motions into one object was pure genius. Nobody had ever conceived of that sort of thing. By analyzing the landing point and some sophisticated solid geometry, he was able to extrapolate to perfect conditions and assert that the trajectory that the ball followed was that of a parabola.

Now let’s take this to the act of actually throwing something. Refer to
Fig.\~[projectile].

Here I’ve put on the diagram the separate components of the ball’s velocity, horizontal and vertical. Throughout the path the horizontal velocity that the thrower originally provided (because she didn’t throw the ball straight up, but at an angle relative to the horizontal) is unchanged.

But the vertical component of the velocity points up until the top. Then, down on the way, well, down. If you’ve ever watched a towering home run, you know that the baseball does not follow a perfect parabola. Rather it falls to Earth relatively more quickly than it took off and so the trajectory is shorter down than up. The forces that an actual ball feels are two: there’s the force of the Earth’s gravity, always down. But there’s also the force of resistance that the air presents to the ball and its direction is precisely the opposite of the ball’s actual direction. The faster the ball goes, in most instances in a fluid, the harder that force of resistance becomes. So as the ball gains speed from gravity, it loses some speed due to deceleration from resistance force…which increases as the ball falls and hence changes the trajectory from parabolic.

<span>\*\*Projectiles on the Earth follow essentially parabolic
trajectories.\*\*</span>

In Chapter [diagrammatica1] we’ll begin to develop a graphical way to approach things that move. We’re going to learn to draw Feynman Diagrams in Spacetime. Not your father’s physics book, this one.

# The Beginning of Physics

When Galileo reached the conclusion that all objects fall to Earth with the same acceleration, he was going against what he—and Aristotle, and everyone else—actually observed. An iron cannonball *would* be observed to reach the ground faster than a wooden one and as you saw in your crumpled paper experiment from page , the same object would be observed to fall at different rates depending on its shape. So how in the world could he insist that there is a uniform rule, in spite of these undeniably different outcomes?

Today you’d say “wind resistance” as an explanation of any differences observed of falling objects and you would be right. But for a 17th century thinker, this was a stretch. Galileo said that it’s not sufficient to just observe and describe what happens because effects like friction are hiding what Nature *really wants* to do! And uncovering those hidden rules is his science...and ours.

## The Red Pill, or the Blue Pill?

This is very un-Aristotle. First of all, Aristotle would never have countenanced doing experiments. You can look at Nature, but don’t touch. But Galileo was all about constructing experiments and making quantitative measurements of what he observed. This was largely new and recognizably “modern.” But there’s more. To him Nature’s rules are hidden to us. We can get close to them by reducing marginal effects like friction but then we have to extrapolate from what we see in our rough and ready laboratory to the hidden rules of a more perfect world. The pendulum bob gets close when it swings back, but the actual rule driving the motion would instruct the pendulum bob to come all the way back to the original height. That’s what’s real.

<mark>I cannot over-emphasize how important this is.</mark> This is very much Plato’s view of Nature, not Aristotle’s. For Plato, The Real was perfect and with our poor, corrupt visual tools we can only perceive inferior copies of the real things—Platonic Ideals. While there is much that’s wrong with Plato’s philosophy, the uncovering of Nature’s hidden order—free of imperfection—is the goal of modern science.

## The Father of Physics

Nobody had ever done what Galileo did in all of history. Let’s summarize his strategies:

**First**, Galileo chose not to explain Nature (motion in his case) on the basis of logical argument from within pre-conditioned philosophy (neither Aristotle’s nor the Church’s): Galileo confronted Nature without precondition: he assumed that Authority did not dictate how the physical world behaves.

**Second**, rather than sit passively and observe, Galileo created artificial circumstances designed to explore particular questions: he assumed that Nature can be characterized by doing experiments.

**Third**, rather than report results as a narrative, Galileo made quantitative measurements under the assumption that arithmetical and geometrical constructions were the appropriate way to describe physical behavior. This idea that Nature appears to be have according to mathematics is not new (going back to at least Pythagoras) and is the bedrock of modern physics. We don't understand it!

<aside style="font-size:80%; font-family:sans-serif; color:rgba(149,168,99,0.8);float:right;width:50%;padding-left:20px; padding-bottom:20px;"> Why does Nature appear to be organized in a way that can be described using mathematics? We don't know! It's a long-standing puzzle. Somehow "it just is" is a less than satisfactory answer but also "mathematics is magic" seems also to be sort of a reach. Most of us go with...it just is, and boy is that lucky.</aside>

The first three strategies alone would make Galileo one of the first, great scientists. But he went further, and his Physics Paternity comes from his *Platonism*.

**Fourth**, Galileo chose to interpret Nature as consisting of rules that can only be discovered by going beyond the rough regularities that we always see in our observations. Nature is best assumed to be simple and mathematical, but all that we can observe is complicated by extraneous effects and the true Nature...um, of Nature is hidden, just out of grasp. Strip away complications like friction as best you can and through mathematical modeling and extrapolation we can uncover Nature’s hidden rules.

Without this **fourth** strategy, physics would be impossible.

<mark>The rules of Nature are often hidden from experiment and must be
inferred by a combination of theoretical modeling and experimental
confirmation.</mark>

Taken together, these five strategies form the modern-looking Nature of physics.

[^1]: or feet per second per second, or miles per hour per hour

[^2]: Notice that the maximum distance in the right hand figure is 100
	m, reached in about 10 seconds. Usain Bolt’s world record is 9.58 s.
